Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8587)

Unified Diff: chrome/test/data/android/payments/name_and_free_shipping.js

Issue 2368073002: PaymentRequest: Add payer name field to payer info editor. (android) (Closed)
Patch Set: PaymentRequest: Add payer name field to payer info editor. (android) Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/test/data/android/payments/name_and_free_shipping.js
diff --git a/chrome/test/data/android/payments/phone_and_free_shipping.js b/chrome/test/data/android/payments/name_and_free_shipping.js
similarity index 85%
copy from chrome/test/data/android/payments/phone_and_free_shipping.js
copy to chrome/test/data/android/payments/name_and_free_shipping.js
index 3018f327200d81c6525191b328439c9fb0981fba..1f3823d860d045dd4dc9ffddc56221159155983f 100644
--- a/chrome/test/data/android/payments/phone_and_free_shipping.js
+++ b/chrome/test/data/android/payments/name_and_free_shipping.js
@@ -8,7 +8,7 @@
/* global toDictionary:false */
/**
* Launches the PaymentRequest UI that request a phone number and offers free
* shipping worldwide.
*/
function buy() { // eslint-disable-line no-unused-vars
@@ -23,13 +23,13 @@ function buy() { // eslint-disable-line no-unused-vars
selected: true
}]
},
- {requestPayerPhone: true, requestShipping: true});
+ {requestPayerName: true, requestShipping: true});
request.show()
.then(function(resp) {
resp.complete('success')
.then(function() {
print(
- resp.payerPhone + '<br>' + resp.shippingOption + '<br>' +
+ resp.payerName + '<br>' + resp.shippingOption + '<br>' +
JSON.stringify(
toDictionary(resp.shippingAddress), undefined, 2) +
'<br>' + resp.methodName + '<br>' +
@@ -8,7 +8,7 @@
/* global toDictionary:false */
/**
- * Launches the PaymentRequest UI that request a phone number and offers free
+ * Launches the PaymentRequest UI that request a payer name and offers free
* shipping worldwide.
*/

Powered by Google App Engine
This is Rietveld 408576698